============================================
 osc_placement Release Notes
============================================

.. toctree::
   :maxdepth: 1

   unreleased
   zed
   yoga
   wallaby
   victoria
   ussuri
   train
   stein
   rocky
   queens
